@@ -19,7 +19,7 @@ class QuietLoop(BaseLoop):
                 # broken pipe
                 self._logger.debug(value)
             else:
-                self.print_exception(context, type, value, tb)
+                self.error_handler.print_exception(context, type, value, tb)
                 #logger.error('', exc_info=(type, value, tb))
 
         if context is None or issubclass(type, Hub.SYSTEM_ERROR):
